@@ -1,7 +1,8 @@
-from PySide2 import QtWidgets
+from qtpy import QtWidgets
+
+from compas_view2.objects import DATA_OBJECT
 
 from .form import Form
-from ..objects.object import DATA_OBJECT
 
 
 class AddForm(Form):
